@@ -1,5 +1,5 @@
 from forge_sdk import did
 from forge_sdk import mcrypto
 from forge_sdk import protos
-from forge_sdk import rpc
 from forge_sdk import utils
+from forge_sdk.sdk import ForgeConn
