@@ -17,6 +17,7 @@ ROLE_MAP = {
     'validator': 8,
     'group': 9,
     'tx': 10,
+    'tether': 11,
     'any': 63,
 }
 
@@ -26,7 +27,7 @@ KEY_MAP = {
 }
 
 HASH_MAP = {
-    'keecak': 0,
+    'keccak': 0,
     'sha3': 1,
     'keccak_384': 2,
     'sha3_384': 3,
