@@ -588,7 +588,8 @@ class ForgeRpc:
         return protos.AssetSpec(address=create_asset_itx.address,
                                 data=json.dumps(spec_data))
 
-    def send_itx(self, tx, wallet, token=None, type_url=None, nonce=RAND_NONCE):
+    def send_itx(self, tx, wallet, token=None, type_url=None,
+                 nonce=RAND_NONCE):
         """
         GRPC call to send inner transaction
 
@@ -628,70 +629,30 @@ class ForgeRpc:
                                   token=token)
         return self.chain_rpc.send_tx(tx)
 
-    def prepare_deposit_tether_tx(self, wallet, token=None, **kwargs):
-        # signed by buyer
-        itx = protos.DepositTetherTx(
-            value=utils.int_to_biguint(kwargs.get('value')),
-            commission=utils.int_to_biguint(kwargs.get('commission')),
-            charge=utils.int_to_biguint(kwargs.get('charge')),
-            target=kwargs.get('target'),
-            withdrawer=kwargs.get('withdrawer'),
-            locktime=kwargs.get('locktime')
-        )
-        return self.build_signed_tx(
-            itx=utils.encode_to_any('fg:t:deposit_tether', itx),
-            wallet=wallet,
-            token=token)
+    def deploy_protocol(self, text, wallet, token=None):
+        """
+        This helper function helps deploy a pre-compiled transaction protocol
+        Args:
+            text(string): output of forge compiler; a precompiled and encoded
+                :obj:`DeployProtocolTx`
+            wallet(:obj:`WalletInfo`): wallet to build the tx
+            token(string): only required if wallet doesn't include secret key
 
-    def finalize_deposit_tether_tx(self, tx, wallet, token=None, data=None):
-        return self.build_multisig_tx(tx=tx, wallet=wallet, token=token,
-                                      data=data)
+        Returns:
+            :obj:`ResponseSendTx`
+        """
+        itx = utils.parse_to_proto(utils.multibase_b64decode(text),
+                                   protos.DeployProtocolTx)
 
-    def prepare_exchange_tether(self, wallet, sender, receiver, expired_at,
-                                data=None,
-                                token=None):
-        itx = protos.ExchangeTetherTx(sender=sender,
-                                      receiver=receiver,
-                                      expired_at=expired_at,
-                                      data=data)
-        return self.build_signed_tx(itx=itx, type_url='fg:t:exchange_tether',
-                                    wallet=wallet,
-                                    token=token)
+        itx.address = did.get_tx_address(itx)
+        return self.send_itx(tx=itx, wallet=wallet, token=token,
+                             type_url='fg:t:deploy_protocol',
+                             nonce=0)
 
-    def finalize_exchange_tether_tx(self, tx, wallet, token=None, data=None):
-        return self.build_multisig_tx(tx=tx, wallet=wallet, token=token,
-                                      data=data)
+    def poke(self, wallet, token=None):
+        itx = utils.build_poke_itx()
+        return self.send_itx(tx=itx, wallet=wallet, token=token, nonce=0)
 
-    def revoke_tether(self, wallet, tether, data=None, token=None,
-                      chain_id=None):
-        itx = protos.RevokeTetherTx(tether=tether, data=data)
-
-        return self.send_itx(tx=itx, type_url='fg:t:revoke_tether',
-                             wallet=wallet,
-                             token=token)
-
-    def approve_tether(self, wallet, withdraw, data=None, token=None,
-                       chain_id=None):
-        itx = protos.ApproveTetherTx(withdraw=withdraw, data=data)
-
-        return self.send_itx(tx=itx, type_url='fg:t:approve_tether',
-                             wallet=wallet,
-                             token=token)
-
-    def withdraw_tether(self, wallet, token=None, **kwargs):
-        params = {
-            'from': kwargs.get('from'),
-            'nonce': kwargs.get('nonce'),
-            'chain_id': kwargs.get('chain_id'),
-            'pk': kwargs.get('pk'),
-            'signature': kwargs.get('signature'),
-            'signatures': kwargs.get('signatures'),
-            'sender': kwargs.get('sender'),
-            'receiver': kwargs.get('receiver'),
-            'expired_at': kwargs.get('expired_at'),
-            'data': kwargs.get('data'),
-        }
-        itx = protos.WithdrawTetherTx(**params)
-        return self.send_itx(tx=itx, type_url='fg:t:withdraw_tether',
-                             wallet=wallet,
-                             token=token)
+    def transfer(self, wallet, to, value=None, assets=None, data=None, token=None):
+        itx = utils.build_transfer_itx(to, value, assets, data)
+        return self.send_itx(tx=itx, wallet=wallet, token=token)
