@@ -22,6 +22,10 @@ class ForgeConn:
 
         self.rpc = self._connect_rpc()
         self.config = self._get_config()
+        self.rpc.__setattr__('chain_id', self.config.chain_id)
+
+        self.token_decimal = self.config.decimal
+        self.symbol = self.config.symbol
 
     def _connect_rpc(self):
         return ForgeRpc(self.channel)
@@ -29,3 +33,9 @@ class ForgeConn:
     def _get_config(self):
         config = self.rpc.get_config().config
         return ForgeConfig(json.loads(config))
+
+    def to_unit(self, token):
+        return int(token * (10 ** int(self.token_decimal)))
+
+    def from_unit(self, unit):
+        return int(unit / (10 ** int(self.token_decimal)))
